@@ -3,7 +3,7 @@ package lazy;
 use strict;
 use warnings;
 
-our $VERSION = '0.000006';
+our $VERSION = '0.000007';
 
 use App::cpm 0.975;    # CLI has no $VERSION
 use App::cpm::CLI;
@@ -82,16 +82,36 @@ sub import {
     push @INC, sub {
         shift;
 
-        # Don't try to install if we're called inside an eval
-        my @caller = caller(1);
-        return
-            if ( ( $caller[3] && $caller[3] =~ m{eval} )
-            || ( $caller[1] && $caller[1] =~ m{eval} ) );
-
         my $name = shift;
         $name =~ s{/}{::}g;
         $name =~ s{\.pm\z}{};
 
+        # Don't try to install if we're called inside an eval
+        # See https://stackoverflow.com/questions/51483287/how-to-detect-if-perl-code-is-being-run-inside-an-eval/
+        for my $level ( 0 .. 20 ) {
+            my @caller = caller($level);
+            last unless @caller;
+
+            if (
+                (
+                       ( $caller[1] && $caller[1] =~ m{eval} )
+                    || ( $caller[3] && $caller[3] =~ m{eval} )
+                )
+                && ( $caller[0] ne 'Capture::Tiny' )
+            ) {
+                my @args = (
+                    $caller[0], $name, $name, $caller[1], $caller[2],
+                    $caller[0]
+                );
+                warn sprintf( <<'EOF', @args );
+Code in package "%s" is attempting to load %s from inside an eval, so we are not installing %s.
+See %s at line %s
+Please open an issue if %s should be whitelisted.
+EOF
+                return;
+            }
+        }
+
         $cpm->run( 'install', @args, $name );
         return 1;
     }, @INC;
@@ -147,7 +167,7 @@ lazy - Lazily install missing Perl modules
 
 =head1 VERSION
 
-version 0.000006
+version 0.000007
 
 =head1 SYNOPSIS
 
@@ -218,6 +238,14 @@ Just make sure that you C<use local::lib> before you C<use lazy>.
 
 * Don't pass the C<-L> or C<--local-lib-contained> args directly to C<lazy>.  Use L<local::lib> directly to get the best (and least confusing) results.
 
+* Right now C<lazy> will not attempt to install modules which are loaded inside
+an C<eval>.  (The exception is code which is run via L<Capture::Tiny>).  This
+prevents attempted installs of some optional modules as well as modules which
+may be OS-specific.  If you think this is wrong, would like to see an option to
+disable this,  or would like to whitelist additional modules, please open an
+issue.  I'm happy to discuss this.  Currently C<lazy> will C<warn> in these
+instances in order to help with debugging failed installs.
+
 * Remove C<lazy> before you put your work into production.
 
 =head2 SEE ALSO
